@@ -3,6 +3,7 @@ package manifest
 var manifestPaths = &manifestPath{
 	local: map[string]string{
 		"firefox":  "~/.mozilla/native-messaging-hosts",
+		"floorp":   "~/.floorp/native-messaging-hosts",
 		"chrome":   "~/.config/google-chrome/NativeMessagingHosts",
 		"chromium": "~/.config/chromium/NativeMessagingHosts",
 		"brave":    "~/.config/BraveSoftware/Brave-Browser/NativeMessagingHosts",
@@ -12,6 +13,7 @@ var manifestPaths = &manifestPath{
 	},
 	global: map[string]string{
 		"firefox":  "mozilla/native-messaging-hosts", // will be prefixed with the appropriate lib path
+		"floorp":   "floorp/native-messaging-hosts",  // will be prefixed with the appropriate lib path
 		"chrome":   "/etc/opt/chrome/native-messaging-hosts",
 		"chromium": "/etc/chromium/native-messaging-hosts",
 		"brave":    "/etc/opt/chrome/native-messaging-hosts",
