@@ -6,12 +6,12 @@ package manifest
 import (
 	"testing"
 
-	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestManifest(t *testing.T) {
 	t.Parallel()
 
 	_, err := getLocation("foobar", "", false)
-	assert.Error(t, err)
+	require.Error(t, err)
 }
