@@ -27,7 +27,7 @@ func TestRender(t *testing.T) {
 	manifestGolden := `{
     "name": "com.justwatch.gopass",
     "description": "Gopass wrapper to search and return passwords",
-    "path": "` + strings.Replace(binDir, "\\", "\\\\", -1) + `",
+    "path": "` + strings.ReplaceAll(binDir, "\\", "\\\\") + `",
     "type": "stdio",
     "allowed_origins": [
         "chrome-extension://kkhfnlkhiapbiehimabddjbimfaijdhk/"
@@ -58,7 +58,7 @@ func TestValidBrowsers(t *testing.T) {
 	case "windows": // Windows
 		validBrowsers = []string{"chrome", "chromium", "firefox"}
 	case "linux": // Linux
-		validBrowsers = []string{"brave", "chrome", "chromium", "firefox", "iridium", "slimjet", "vivaldi"}
+		validBrowsers = []string{"brave", "chrome", "chromium", "firefox", "floorp", "iridium", "slimjet", "vivaldi"}
 	case "freebsd": // FreeBSD
 		validBrowsers = []string{"chrome", "chromium", "ungoogled-chromium", "firefox", "iridium"}
 	default: // Fallback, not suppoerted OS
