@@ -6,23 +6,23 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestRoundTrip(t *testing.T) {
 	t.Parallel()
 
-	a := assert.New(t)
 	var receivedMessage queryMessage
 
 	message := queryMessage{Query: "holla"}
 	var buffer bytes.Buffer
 
 	err := sendResponse(message, &buffer)
-	a.NoError(err)
+	require.NoError(t, err)
 
 	received, err := readRequest(&buffer)
-	a.NoError(err)
+	require.NoError(t, err)
 
-	a.NoError(json.Unmarshal(received, &receivedMessage))
-	a.Equal(message.Query, receivedMessage.Query)
+	require.NoError(t, json.Unmarshal(received, &receivedMessage))
+	assert.Equal(t, message.Query, receivedMessage.Query)
 }
